;; Generated package description from keymap-popup.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "keymap-popup" "0.3.1.0.20260530.4" "Described keymaps with popup help" '((emacs "29.1")) :commit "72e406033618b49571ab2895bf183ce23aa7b21f" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("convenience") :url "https://codeberg.org/thanosapollo/emacs-keymap-popup")
